@@ -1,9 +1,8 @@
-from .utils import draw_title
+from .utils import draw_title, BASE_DIR
 from PIL import Image
 import argparse
 import os
 
-BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 
 if __name__ == "__main__":
 
@@ -19,8 +18,11 @@ if __name__ == "__main__":
     # layer = input("Digite o nome da camada: ")
     # version = input("Digite a versão da aplicação: ")
 
-    background_img = Image.open(f'{BASE_DIR}/assets/background.png')
+    background_img = Image.open(f'{BASE_DIR}/assets/images/background.png')
 
     final_img = draw_title(background_img, args.project, f'{args.layer} - {args.version}')
 
-    final_img.save(f'{args.output_dir}/{args.project}_{args.layer}_tumbnail_{args.version}.png')
+    filepath = f'{args.output_dir}/{args.project}_{args.layer}_tumbnail_{args.version}.png'
+    final_img.save(filepath)
+
+    os.system(filepath)
